@@ -129,6 +129,15 @@ def baidu_download(url, output_dir='.', stream_type=None, merge=True, info_only=
             html = get_html(url)
             title = r1(r'title:"([^"]+)"', html)
 
+            vhsrc = re.findall(r'vhsrc="([^"]+)"', html)
+            if vhsrc is not None:
+                ext = 'mp4'
+                size = url_size(vhsrc[0])
+                print_info(site_info, title, ext, size)
+                if not info_only:
+                    download_urls(vhsrc, title, ext, size,
+                                  output_dir=output_dir, merge=False)
+
             items = re.findall(
                 r'//imgsrc.baidu.com/forum/w[^"]+/([^/"]+)', html)
             urls = ['http://imgsrc.baidu.com/forum/pic/item/' + i
