@@ -27,6 +27,8 @@ def instagram_download(url, output_dir='.', merge=True, info_only=False, **kwarg
             for edge in edges:
                 title = edge['node']['shortcode']
                 image_url = edge['node']['display_url']
+                if 'video_url' in edge['node']:
+                    image_url = edge['node']['video_url']
                 ext = image_url.split('.')[-1]
                 size = int(get_head(image_url)['Content-Length'])
                 print_info(site_info, title, ext, size)
@@ -39,6 +41,8 @@ def instagram_download(url, output_dir='.', merge=True, info_only=False, **kwarg
         else:
             title = info['entry_data']['PostPage'][0]['graphql']['shortcode_media']['shortcode']
             image_url = info['entry_data']['PostPage'][0]['graphql']['shortcode_media']['display_url']
+            if 'video_url' in info['entry_data']['PostPage'][0]['graphql']['shortcode_media']:
+                image_url =info['entry_data']['PostPage'][0]['graphql']['shortcode_media']['video_url']
             ext = image_url.split('.')[-1]
             size = int(get_head(image_url)['Content-Length'])
             print_info(site_info, title, ext, size)
