@@ -1,5 +1,6 @@
 #!/usr/bin/env python
-__all__ = ['ixigua_download', 'ixigua_download_playlist']
+__all__ = ['ixigua_download']
+
 from .toutiao import download as toutiao_download
 from .toutiao import download_playlist as toutiao_download_playlist
 
@@ -10,4 +11,4 @@ def ixigua_download(url, output_dir='.', merge=True, info_only=False, **kwargs):
 
 site_info = "ixigua.com"
 download = ixigua_download
-download_playlist = toutiao_download_playlist
\ No newline at end of file
+download_playlist = toutiao_download_playlist
