@@ -89,10 +89,10 @@ def e(message, exit_code=None):
     """Print an error log message."""
     print_log(message, YELLOW, BOLD)
     if exit_code is not None:
-        exit(exit_code)
+        sys.exit(exit_code)
 
 def wtf(message, exit_code=1):
     """What a Terrible Failure!"""
     print_log(message, RED, BOLD)
     if exit_code is not None:
-        exit(exit_code)
+        sys.exit(exit_code)
